# Optimization of stable radicals for organic redox flow batteries

Demonstration of radical optimization as detailed in

Sowndarya S. V., S., Law, J., Tripp, C., Duplyakin, D., Skordilis, E., Biagioni, D.,
Paton, R., & St. John, P. (2021). Multi-objective goal-directed optimization of de novo
stable organic radicals for aqueous redox flow batteries. *Nat Mach Intell* (in press) 
https://doi.org/10.1038/s42256-022-00506-3

Other requirements include

* Models for oxidation / reduction potential and radical stability,
  https://github.com/pstjohn/redox-models (will download automatically via
  [pooch](https://pypi.org/project/pooch/))

* [alfabet](https://github.com/nrel/alfabet) for BDE predictions

